==> webkitgtk-2.39.5.tar.xz: webkitgtk-2.39.5/Source/JavaScriptCore/wasm/WasmCompilationMode.cpp <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WasmCompilationMode.h"

#include "Options.h"
#include <wtf/Assertions.h>

namespace JSC { namespace Wasm {

const char* makeString(CompilationMode mode)
{
    switch (mode) {
    case CompilationMode::LLIntMode:
        return "LLInt";
    case CompilationMode::BBQMode:
        return "BBQ";
    case CompilationMode::BBQForOSREntryMode:
        return "BBQForOSREntry";
    case CompilationMode::OMGMode:
        return "OMG";
    case CompilationMode::OMGForOSREntryMode:
        return "OMGForOSREntry";
    case CompilationMode::EmbedderEntrypointMode:
        return "EmbedderEntrypoint";
    case CompilationMode::JSToWasmICMode:
        return "JSToWasmIC";
    }
    RELEASE_ASSERT_NOT_REACHED();
    return "";
}

} } // namespace JSC::Wasm

==> webkitgtk-2.45.4.tar.xz: webkitgtk-2.45.4/Source/JavaScriptCore/wasm/WasmCompilationMode.cpp <==
/*
 * Copyright (C) 2019 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL APPLE INC. OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WasmCompilationMode.h"

#include "Options.h"
#include <wtf/Assertions.h>

namespace JSC { namespace Wasm {

ASCIILiteral makeString(CompilationMode mode)
{
    switch (mode) {
    case CompilationMode::IPIntMode:
        return "IPInt"_s;
    case CompilationMode::LLIntMode:
        return "LLInt"_s;
    case CompilationMode::BBQMode:
        return "BBQ"_s;
    case CompilationMode::BBQForOSREntryMode:
        return "BBQForOSREntry"_s;
    case CompilationMode::OMGMode:
        return "OMG"_s;
    case CompilationMode::OMGForOSREntryMode:
        return "OMGForOSREntry"_s;
    case CompilationMode::JSEntrypointJITMode:
        return "JSEntrypoint"_s;
    case CompilationMode::JSEntrypointInterpreterMode:
        return "JSEntrypointInterpreter"_s;
    case CompilationMode::JSToWasmICMode:
        return "JSToWasmIC"_s;
    case CompilationMode::WasmToJSMode:
        return "WasmToJS"_s;
    }
    RELEASE_ASSERT_NOT_REACHED();
    return ""_s;
}

} } // namespace JSC::Wasm
